# vim: set ts=4 sw=4 et:

Summary:        SIFT Feature Detection implementation
Name:           autopano-sift-C
Version:        2.5.1
Release:        lp150.3.6
License:        GPLv2, but SIFT algorithm may require license in some countries
Group:          Productivity/Graphics/Other
URL:            http://hugin.sourceforge.net/
# http://prdownloads.sourceforge.net/hugin/%{name}-%{version}.tar.gz
Source0:        %{name}-%{version}.tar.bz2
# add libm to linker, required to build on 12.1 onwards
Patch1:         autopano-sift-C-libm.patch
BuildRoot:      %{_tmppath}/buildroot-%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  libjpeg-devel
BuildRequires:  libpano-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig gcc-c++ make

%description
The SIFT algorithm provides the capability to identify key feature
points within arbitrary images. It further extracts highly distinct
information for each such point and allows to characterize the point
invariant to a number of modifications to the image. It is invariant
to contrast/brightness changes, to rotation, scaling and partially
invariant to other kinds of transformations. The algorithm can be
flexibly used to create input data for image matching, object
identification and other computer vision related algorithms.

autopano-sift-C is a C port of the C# software autopano-sift. It is
somewhat faster and doesn't require a C# runtime. Additionally,
autopano-sift-C has experimental modifications to perform feature
identification in conformal image space, this helps with wide angle or
fisheye Projection photographs.

%prep
%setup -q -n "autopano-sift-C-%{version}"
%patch1

%build
mkdir build
pushd build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
libsuffix=$(echo %_lib | cut -b4-)
cmake \
    -DCMAKE_INSTALL_PREFIX="%{_prefix}" \
    -DCMAKE_VERBOSE_MAKEFILE=TRUE \
    -DCMAKE_SKIP_RPATH=ON \
    -DLIB_SUFFIX="$libsuffix" \
    -DCMAKE_BUILD_TYPE=release \
    ..
%__make VERBOSE=1 %{?_smp_mflags}
popd #build

%install
pushd build
%makeinstall
popd #build

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root,-)
%doc README* LICENSE doc ChangeLog
%{_bindir}/autopano
%{_bindir}/autopano-c-complete.sh
%{_bindir}/autopano-sift-c
%{_bindir}/generatekeys
%doc %{_mandir}/man1/autopano-c-complete.1%{ext_man}
%doc %{_mandir}/man1/autopano.1%{ext_man}
%doc %{_mandir}/man1/generatekeys.1%{ext_man}
%doc %{_mandir}/man7/autopano-sift-c.7%{ext_man}

%changelog
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- add patch to link against libm, in order to fix the build on openSUSE 12.1
  onwards
* Wed Sep  1 2010 pascal@links2linux.de
- initial package (2.5.1)
